@@ -32,7 +32,7 @@ impl Renderer {
             .request_adapter(&wgpu::RequestAdapterOptions {
                 power_preference: wgpu::PowerPreference::LowPower,
                 compatible_surface: Some(&surface),
-                //force_fallback_adapter: false,
+                force_fallback_adapter: false,
             })
             .await
             .unwrap();
@@ -49,9 +49,14 @@ impl Renderer {
             .await
             .unwrap();
 
+        let tex_format = surface.get_preferred_format(&adapter);
         let config = wgpu::SurfaceConfiguration {
             usage: wgpu::TextureUsages::RENDER_ATTACHMENT,
-            format: wgpu::TextureFormat::Bgra8UnormSrgb,
+            format: if tex_format.is_some() {
+                tex_format.unwrap()
+            } else {
+                wgpu::TextureFormat::Bgra8Unorm
+            }, //wgpu::TextureFormat::Bgra8UnormSrgb,
             width: size.width,
             height: size.height,
             present_mode: wgpu::PresentMode::Immediate,
@@ -74,10 +79,8 @@ impl Renderer {
                     wgpu::BindGroupLayoutEntry {
                         binding: 1,
                         visibility: wgpu::ShaderStages::FRAGMENT,
-                        ty: wgpu::BindingType::Sampler {
-                            comparison: false,
-                            filtering: true,
-                        },
+                        ty: wgpu::BindingType::Sampler(wgpu::SamplerBindingType::Filtering), //comparison: false,
+                        // filtering: true,
                         count: None,
                     },
                 ],
@@ -158,7 +161,7 @@ impl Renderer {
         objects: &Vec<Object>,
         camera: &Camera,
     ) -> Result<(), wgpu::SurfaceError> {
-        let frame = self.surface.get_current_frame()?.output;
+        let frame = self.surface.get_current_texture()?;
         let view = frame
             .texture
             .create_view(&wgpu::TextureViewDescriptor::default());
@@ -213,6 +216,7 @@ impl Renderer {
 
         // submit will accept anything that implements IntoIter
         self.queue.submit(std::iter::once(encoder.finish()));
+        frame.present();
 
         Ok(())
     }
