@@ -9,5 +9,5 @@ pub mod camera;
 pub mod default_resources;
 pub mod flycamera;
 
-//#[cfg(target_feature = "model_loader")]
+#[cfg(feature = "model_loader")]
 pub mod loader;
