@@ -7,14 +7,14 @@
 pub const DEFAULT_SHADER: &str = r#"
 // Vertex Stage
 
-[[block]]
+
 struct CameraUniforms {
     camera_matrix: mat4x4<f32>;
 };
 [[group(1), binding(0)]]
 var<uniform> camera_uniform: CameraUniforms;
 
-[[block]]
+
 struct TransformationUniforms {
     transform_matrix: mat4x4<f32>;
 };
@@ -41,7 +41,7 @@ fn vs_main(input: VertexInput) -> VertexOutput {
 
 // Fragment Stage
 
-[[block]]
+
 struct FragmentUniforms {
     color: vec4<f32>;
 };
@@ -89,29 +89,12 @@ pub const DEFAULT_TEXTURE: &[u8] = &[
 
 pub const DEFAULT_COLOR: [f32; 4] = [1.0, 1.0, 1.0, 1.0];
 
-pub const DEFAULT_MATRIX_4: glm::Mat4 = glm::Mat4 {
-    c0: glm::Vector4 {
-        x: 1.0,
-        y: 0.0,
-        z: 0.0,
-        w: 0.0,
-    },
-    c1: glm::Vector4 {
-        x: 0.0,
-        y: 1.0,
-        z: 0.0,
-        w: 0.0,
-    },
-    c2: glm::Vector4 {
-        x: 0.0,
-        y: 0.0,
-        z: 1.0,
-        w: 0.0,
-    },
-    c3: glm::Vector4 {
-        x: 0.0,
-        y: 0.0,
-        z: 0.0,
-        w: 1.0,
-    },
-};
+pub const DEFAULT_MATRIX_4: crate::header::uniform_type::Matrix =
+    crate::header::uniform_type::Matrix {
+        data: [
+            [1.0, 0.0, 0.0, 0.0],
+            [0.0, 1.0, 0.0, 0.0],
+            [0.0, 0.0, 1.0, 0.0],
+            [0.0, 0.0, 0.0, 1.0],
+        ],
+    };
